package common

import (
	"code.electrolab.fr/it/vote.electrolab.fr/application"
	"context"
	"crypto/sha256"
	"database/sql"
	"encoding/hex"
	"fmt"
	"net/http"
)

func GetVoterInfo(app *application.App, ctx context.Context, r *http.Request) (voterPublicId string, voterFullName string, err error) {
	var (
		privateToken    = r.FormValue("private_token")
		privateTokenSha = sha256.Sum256([]byte(privateToken))
		publicId        = hex.EncodeToString(privateTokenSha[:])
		fullName        string
	)
	err = app.DB.QueryRowContext(ctx, `SELECT fullname FROM voters WHERE public_token = $1`, publicId).Scan(&fullName)
	if err != nil {
		if err == sql.ErrNoRows {
			return "", "", fmt.Errorf("Invalid voter private token")
		} else {
			return "", "", fmt.Errorf("Query error: %s", err.Error())
		}
	}
	return publicId, fullName, nil
}
